@@ -37,125 +37,102 @@ LinternaMagica.prototype.create_controls = function(object_data)
 
     var self =this;
 
+    var started_clip = this.find_started_clip();
+
     var play = document.createElement("a");
     play.setAttribute("class", "linterna-magica-controls-buttons "+
 		      "linterna-magica-controls-buttons-play");
     play.setAttribute("href", "#");
-    play.setAttribute("title", _("Play"));
+    play.setAttribute("title", this._("Play"));
     play.textContent ="Pl";
     // Only pause button should be visible on autostart
-    // Auto start only the firs object in the page
-    if (this.autostart && id == 0)
+    // Auto start only if no other clip is playing.
+    if (this.autostart && started_clip == null)
     {
 	play.style.setProperty("display", "none", "important");
     }
 
-    play.addEventListener("click", function(ev)
-    			  {
-    			      ev.preventDefault();
+    var play_click_function = function(ev)
+    {
+    	ev.preventDefault();
 
-			      this.style.
-			       	  setProperty("display",
-			       		      "none", "important");
+	this.style.setProperty("display", "none", "important");
 
-			      this.nextSibling.style.
-				  removeProperty("display");
+	this.nextSibling.style.removeProperty("display");
 
-    			      self.player.play.apply(self, [id]);
+    	self.player.play.apply(self, [id]);
 
-			      // Start the time ticker
-			      self.player_timers[id] =
-				  setInterval(
-				      function()
-				      {
-					  self.ticker.apply(self, [id]);
-				      }, 500);
-    			  }, false);
+	// Start the time ticker
+	self.player_timers[id] = setInterval(
+	    function()
+	    {
+		self.ticker.apply(self, [id]);
+	    }, 500);
+    };
+
+    play.addEventListener("click", play_click_function, false);
     controls.appendChild(play);
 
     var pause = document.createElement("a");
     pause.setAttribute("class", "linterna-magica-controls-buttons "+
 		       "linterna-magica-controls-buttons-pause");
     pause.setAttribute("href", "#");
-    pause.setAttribute("title", _("Pause"));
+    pause.setAttribute("title", this._("Pause"));
     pause.textContent ="Pa";
-    // Only play button should be visible if !autostart (and
-    if (!this.autostart || id !=0)
+    // Only play button should be visible if !autostart or another
+    // clip is strated.
+    if (!this.autostart || started_clip !== null)
     {
 	pause.style.setProperty("display", "none", "important");
     }
 
-    pause.addEventListener("click", function(ev)
-    			   {
-    			       ev.preventDefault();
-			       this.style.
-			       	   setProperty("display",
-			       		       "none", "important");
+    var pause_click_function = function(ev)
+    {
+    	ev.preventDefault();
+	this.style.
+	    setProperty("display", "none", "important");
 
-			       this.previousSibling.style.
-				   removeProperty("display");
+	this.previousSibling.style.removeProperty("display");
 
-    			       self.player.pause.apply(self, [id]);
+    	self.player.pause.apply(self, [id]);
 
-			       // Stop the time ticker
-			       clearInterval(self.player_timers[id]);
-			       delete self.player_timers[id];
-    			   }, false);
+	// Stop the time ticker
+	clearInterval(self.player_timers[id]);
+	delete self.player_timers[id];
+    };
+
+    pause.addEventListener("click", pause_click_function, false);
     controls.appendChild(pause);
 
     var stop = document.createElement("a");
     stop.setAttribute("class", "linterna-magica-controls-buttons "+
 		      "linterna-magica-controls-buttons-stop");
     stop.setAttribute("href", "#");
-    stop.setAttribute("title", _("Stop"));
+    stop.setAttribute("title", this._("Stop"));
     stop.textContent ="St";
-    stop.addEventListener("click", function(ev)
-    			  {
-    			      ev.preventDefault();
-			      // pause
-			      this.previousSibling.style.
-			       	  setProperty("display",
-			       		      "none", "important");
-			      // play
-			      this.previousSibling.previousSibling.
-			       	  style.removeProperty("display");
 
-    			      self.player.stop.apply(self, [id]);
+    var stop_click_function = function(ev)
+    {
+    	ev.preventDefault();
+	// pause
+	this.previousSibling.style.setProperty("display", 
+					       "none", "important");
+	// play button
+	var play = this.previousSibling.previousSibling;
+	play.style.removeProperty("display");
 
-			      // Stop the time ticker
-			      clearInterval(self.player_timers[id]);
-			      delete self.player_timers[id];
-    			  }, false);
+    	self.player.stop.apply(self, [id]);
+
+	// Stop the time ticker
+	clearInterval(self.player_timers[id]);
+	delete self.player_timers[id];
+    };
+
+    stop.addEventListener("click", stop_click_function, false);
     controls.appendChild(stop);
 
-
-    // var seek_b = document.createElement("a");
-    // seek_b.setAttribute("class", "linterna-magica-controls-buttons");
-    // seek_b.setAttribute("href", "#");
-    // seek_b.setAttribute("title", _("Seek 10 seconds backwards"));
-    // seek_b.textContent ="Rw";
-    // seek_b.addEventListener("click", function(ev)
-    // 			    {
-    // 				ev.preventDefault();
-    // 				self.player.rewind.apply(self, [id]);
-    // 			    }, false);
-    // controls.appendChild(seek_b);
-
-    // var seek_f = document.createElement("a");
-    // seek_f.setAttribute("class", "linterna-magica-controls-buttons");
-    // seek_f.setAttribute("href", "#")
-    // seek_f.setAttribute("title", _("Seek 10 seconds forward"));
-    // seek_f.textContent ="Fw";
-    // seek_f.addEventListener("click", function(ev)
-    // 			    {
-    // 				ev.preventDefault();
-    // 				self.player.forward.apply(self, [id]);
-    // 			    }, false);
-    // controls.appendChild(seek_f);
-
-
     var time_slider = document.createElement("div");
-    time_slider.setAttribute("title", _("Time"));
+    time_slider.setAttribute("title", this._("Time"));
 
     time_slider.setAttribute("class",
 			     "linterna-magica-controls-horizontal-slider");
@@ -177,62 +154,69 @@ LinternaMagica.prototype.create_controls = function(object_data)
     var mouse_scroll = /WebKit/i.test(navigator.userAgent) ?
 	"mousewheel" : "DOMMouseScroll";
 
-    time_slider.addEventListener(mouse_scroll, function(ev)
-				 {
-				     ev.preventDefault();
-				     var pos = self.slider_control.
-					 apply(self, [ev]);
+    var time_slider_scroll_function = function(ev)
+    {
+	ev.preventDefault();
+	var pos = self.slider_control.apply(self, [ev]);
 
-				     if (pos.direction > 0)
-				     {
-					 self.player.forward.
-					     apply(self,[id,pos.val])
-				     }
-				     else
-				     {
-					 self.player.rewind.
-					     apply(self,[id,pos.val])
-				     }
+	if (pos.direction > 0)
+	{
+	    self.player.forward.apply(self,[id,pos.val]);
+	}
+	else
+	{
+	    self.player.rewind.apply(self,[id,pos.val]);
+	}
+    };
 
-				 }, false);
+    time_slider.addEventListener(mouse_scroll, 
+				 time_slider_scroll_function, false);
 
-    time_slider.addEventListener("click", function(ev)
-				 {
-				     ev.preventDefault();
-				     // Stop the time ticker
-				     clearInterval(self.player_timers[id]);
-				     delete self.player_timers[id];
+    var time_slider_click_function =  function(ev)
+    {
+	ev.preventDefault();
+	// Stop the time ticker
+	clearInterval(self.player_timers[id]);
+	delete self.player_timers[id];
 
-				     var pos =
-					 self.slider_control.
-					 apply(self, [ev]);
+	var pos =  self.slider_control.apply(self, [ev]);
 
-				     if (pos.direction > 0)
-				     {
-					 self.player.forward.
-					     apply(self,[id,pos.val])
-				     }
-				     else
-				     {
-					 self.player.rewind.
-					     apply(self,[id,pos.val])
-				     }
+	if (pos.direction > 0)
+	{
+	    self.player.forward.apply(self,[id,pos.val]);
+	}
+	else
+	{
+	    self.player.rewind.apply(self,[id,pos.val]);
+	}
 
-				     self.player_timers[id] =
-					 setInterval(
-					     function()
-					     {
-						 self.ticker.apply(self,[id]);
-					     }, 500);
-				 }, false);
+	self.player_timers[id] = setInterval(
+	    function()
+	    {
+		self.ticker.apply(self,[id]);
+	    }, 500);
+    };
 
+    time_slider.addEventListener("click", time_slider_click_function, false);
+
+    var time_knob_move = null;
+
+    if (this.languages[this.lang].__direction == "ltr" ||
+	this.languages[this.lang].__direction !== "rtl")
+    {
+	time_knob_move = "left";
+    }
+    else if (this.languages[this.lang].__direction == "rtl")
+    {
+	time_knob_move = "right";
+    }
 
     var time_knob = document.createElement("a");
-    time_knob.setAttribute("title", _("Time"));
+    time_knob.setAttribute("title", this._("Time"));
     time_knob.setAttribute("class", "linterna-magica-controls-slider-knob");
     time_knob.setAttribute("id",
 			   "linterna-magica-controls-time-slider-knob-"+id);
-    time_knob.style.setProperty("left", "0px", "important");
+    time_knob.style.setProperty(time_knob_move, "0px", "important");
 
     time_knob.setAttribute("href", "#");
     time_knob.addEventListener("mousedown", function(ev)
@@ -267,7 +251,7 @@ LinternaMagica.prototype.create_controls = function(object_data)
     var volume_slider = document.createElement("div");
     volume_slider.setAttribute("class",
 			       "linterna-magica-controls-horizontal-slider");
-    volume_slider.setAttribute("title", _("Volume control"));
+    volume_slider.setAttribute("title", this._("Volume control"));
 
     // The slider width is calculated from
     // the object width.  We have 6 buttons
@@ -281,31 +265,43 @@ LinternaMagica.prototype.create_controls = function(object_data)
 				    volume_width+"px",
 				    "important");
 
-    volume_slider.addEventListener(mouse_scroll, function(ev)
-				   {
-				       ev.preventDefault();
-				       var pos =
-					   self.slider_control.
-					   apply(self, [ev]);
+    var volume_slider_scroll_function = function(ev)
+    {
+	ev.preventDefault();
+	var pos = self.slider_control.apply(self, [ev]);
 
-				       self.player.set_volume.
-					   apply(self, [id, pos.val]);
+	self.player.set_volume.apply(self, [id, pos.val]);
 
-				       volume_text.textContent = pos.val;
-				   }, false);
+	volume_text.textContent = pos.val;
+    };
 
-    volume_slider.addEventListener("click", function(ev)
-				   {
-				       ev.preventDefault();
-				       var pos =
-					   self.slider_control.
-					   apply(self, [ev]);
+    volume_slider.addEventListener(mouse_scroll,
+				   volume_slider_scroll_function, false);
 
-				       self.player.set_volume.
-					   apply(self, [id, pos.val]);
+    var volume_slider_click_function = function(ev)
+    {
+	ev.preventDefault();
+	var pos = self.slider_control.apply(self, [ev]);
 
-				       volume_text.textContent = pos.val;
-				   }, false);
+	self.player.set_volume.apply(self, [id, pos.val]);
+
+	volume_text.textContent = pos.val;
+    };
+
+    volume_slider.addEventListener("click",
+				   volume_slider_click_function, false);
+
+    var volume_knob_move = null;
+
+    if (this.languages[this.lang].__direction == "ltr" ||
+	this.languages[this.lang].__direction !== "rtl")
+    {
+	volume_knob_move = "left";
+    }
+    else if (this.languages[this.lang].__direction == "rtl")
+    {
+	volume_knob_move = "right";
+    }
 
     var volume_knob = document.createElement("a");
     volume_knob.setAttribute("class", "linterna-magica-controls-slider-knob");
@@ -316,9 +312,9 @@ LinternaMagica.prototype.create_controls = function(object_data)
     // volume_knob.style.setProperty("width",
     // 				  parseInt(volume_width*10/100)+"px",
     // 				  "important");
-    volume_knob.style.setProperty("left", "0px", "important");
+    volume_knob.style.setProperty(volume_knob_move, "0px", "important");
     volume_knob.setAttribute("href", "#");
-    volume_knob.setAttribute("title", _("Volume control"));
+    volume_knob.setAttribute("title", this._("Volume control"));
     volume_knob.addEventListener("mousedown", function(ev)
 				 {
 				     ev.preventDefault();
@@ -329,7 +325,8 @@ LinternaMagica.prototype.create_controls = function(object_data)
 
     controls.appendChild(volume_slider);
 
-    volume_text.setAttribute("class", "linterna-magica-controls-slider-text");
+    volume_text.setAttribute("class",
+			     "linterna-magica-controls-slider-text");
 
     volume_text.style.setProperty("left",
 				  parseInt(volume_width/3)+"px",
@@ -342,56 +339,57 @@ LinternaMagica.prototype.create_controls = function(object_data)
     mute.setAttribute("class", "linterna-magica-controls-buttons "+
 		      "linterna-magica-controls-buttons-mute");
     mute.setAttribute("href", "#");
-    mute.setAttribute("title", _("Mute"));
+    mute.setAttribute("title", this._("Mute"));
     mute.textContent ="M";
 
-    mute.addEventListener("click", function(ev)
-			  {
-			      ev.preventDefault();
-			      var volume =
-				  self.player.toggle_mute.apply(self,[id]);
+    var mute_click_function = function(ev)
+    {
+	ev.preventDefault();
+	var volume =
+	    self.player.toggle_mute.apply(self,[id]);
 
-			      if (/M/i.test(mute.textContent))
-			      {
-				  mute.textContent = "U";
-				  mute.setAttribute("title", _("Unmute"));
+	if (/M/i.test(mute.textContent))
+	{
+	    mute.textContent = "U";
+	    mute.setAttribute("title", self._.apply(self, ["Unmute"]));
 
-				  mute.setAttribute(
-				      "class",
-				      "linterna-magica-controls-buttons "+
-					  "linterna-magica-controls-"+
-					  "buttons-unmute");
-				  volume_text.textContent = "0%";
-				  volume_text.setAttribute("title",
-							   _("Muted"));
-				  volume_slider.setAttribute("title",
-							     _("Muted"));
-				  volume_knob.setAttribute("title",
-							   _("Muted"));
-			      }
-			      else
-			      {
-				  mute.textContent = "M";
-				  mute.setAttribute("title", _("Mute"));
-				  volume_text.textContent = volume;
+	    mute.setAttribute(
+		"class",
+		"linterna-magica-controls-buttons "+
+		    "linterna-magica-controls-"+
+		    "buttons-unmute");
 
-				  volume_text.removeAttribute("title");
-				  mute.setAttribute(
-				      "class",
-				      "linterna-magica-controls-buttons "+
-					  "linterna-magica-controls-"+
-					  "buttons-mute");
+	    volume_text.textContent = "0%";
+	    volume_text.setAttribute("title",
+				     self._.apply(self, ["Muted"]));
+	    volume_slider.setAttribute("title",
+				       self._.apply(self, ["Muted"]));
+	    volume_knob.setAttribute("title",
+				     self._.apply(self, ["Muted"]));
+	}
+	else
+	{
+	    mute.textContent = "M";
+	    mute.setAttribute("title", self._.apply(self, ["Mute"]));
+	    volume_text.textContent = volume;
 
-				  volume_slider.
-				      setAttribute("title",
-						   _("Volume control"));
-				  volume_knob.
-				      setAttribute("title",
-						   _("Volume control"));
-			      }
+	    volume_text.removeAttribute("title");
+	    mute.setAttribute(
+		"class",
+		"linterna-magica-controls-buttons "+
+		    "linterna-magica-controls-"+
+		    "buttons-mute");
 
+	    volume_slider.
+		setAttribute("title",
+			     self._.apply(self, ["Volume control"]));
+	    volume_knob.
+		setAttribute("title",
+			     self._.apply(self, ["Volume control"]));
+	}
+    };
 
-			  },false);
+    mute.addEventListener("click", mute_click_function, false);
     controls.appendChild(mute);
 
     var fullscreen = document.createElement("a");
@@ -399,13 +397,17 @@ LinternaMagica.prototype.create_controls = function(object_data)
 	"class", "linterna-magica-controls-buttons "+
 	    "linterna-magica-controls-buttons-fullscreen");
     fullscreen.setAttribute("href", "#");
-    fullscreen.setAttribute("title", _("Fullscreen"));
+    fullscreen.setAttribute("title", this._("Fullscreen"));
     fullscreen.textContent ="Fs";
-    fullscreen.addEventListener("click", function(ev)
-    				{
-    				    ev.preventDefault();
-    				    self.player.fullscreen.apply(self, [id]);
-    				}, false);
+
+    var fullscreen_click_function = function(ev)
+    {
+    	ev.preventDefault();
+    	self.player.fullscreen.apply(self, [id]);
+    };
+    				
+    fullscreen.addEventListener("click",
+				fullscreen_click_function, false);
     controls.appendChild(fullscreen);
 
     return controls;
